#  view.rb - main script
#  Copyright (C) 2004-2007 Frédéric Logier

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


require 'singleton'
require 'libglade2'
require 'gdk_pixbuf2'
require 'gnome2'


#require 'geekast/ui/callback'
#require 'geekast/ui/interface'

require 'geekast/views/lib/ui'

module Geekast
  module View

    def self.main
      Interface.instance
    end


    #######
    private
    #######

    class Interface < Sig
      include Singleton

      def initialize
        puts "View singleton launched" if $DEBUG

        Gnome::Program.new(NAME, VERSION)
        UI.new
        Gtk.main
        #        $mainloop = GLib::MainLoop.new(nil, true)
        #  puts $mainloop.methods
        # $mainloop.run
      end

    end

  end
end
